Actions, Resources, and Condition Keys for AWS IQ - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IQ.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for AWS IQ

AWS IQ (service prefix: `iq`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

Topics

- Actions Defined by AWS IQ
- Resources Defined by AWS IQ
- Condition Keys for AWS IQ

## Actions Defined by AWS IQ

AWS IQ has no API operations that can be used in the `Actions` element of an IAM policy statement. To allow access to AWS IQ, specify `“Action”: “iq:*”` in your policy.

## Resources Defined by AWS IQ

AWS IQ does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS IQ, specify `“Resource”: “*”` in your policy.

## Condition Keys for AWS IQ

IQ has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by AWS IQ
- Resources Defined by AWS IQ
- Condition Keys for AWS IQ

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more